==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/account/data_account_vins_list/main.tf <==
/*
Пример использования
Получение списка vins, используемых аккаунтом
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_account_vins_list" "avl" {
  #id аккаунта
  #обязательный параметр
  #тип - целое число
  account_id = 22222

  #фильтр по id vins
  #опциональный параметр
  #тип - целое число
  #vins_id = 100

  #фильтр по имени vins
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по id ресурсной группы
  #опциональный параметр 
  #тип - целое число
  #rg_id = 11111

  #фильтр по IP внешней сети
  #опциональный параметр
  #тип - строка
  #ext_ip = "test"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 3
}

output "test" {
  value = data.dynamix_account_vins_list.avl
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/account/data_account_vins_list/main.tf <==
/*
Пример использования
Получение списка vins, используемых аккаунтом
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_account_vins_list" "avl" {
  #id аккаунта
  #обязательный параметр
  #тип - целое число
  account_id = 22222

  #фильтр по id vins
  #опциональный параметр
  #тип - целое число
  #vins_id = 100

  #фильтр по имени vins
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по id ресурсной группы
  #опциональный параметр 
  #тип - целое число
  #rg_id = 11111

  #фильтр по IP внешней сети
  #опциональный параметр
  #тип - строка
  #ext_ip = "test"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 3
}

output "test" {
  value = data.dynamix_account_vins_list.avl
}
